# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Defined types

* [`registry::service`](#registry--service): Defined resource type that manages service entries
* [`registry::value`](#registry--value): High level abstraction on top of registry_key and registry_value resources

### Resource types

* [`registry_key`](#registry_key): Manages registry keys on Windows
* [`registry_value`](#registry_value): Manages registry values on Windows systems.

## Defined types

### <a name="registry--service"></a>`registry::service`

Manages the values in the key HKLM\System\CurrentControlSet\Services\$name\

* **Note** This defined resource type manages service entries in the Microsoft service
control framework by managing the appropriate registry keys and values.

This is an alternative approach to using INSTSRV.EXE [1].

[1] http://support.microsoft.com/kb/137890

#### Examples

##### Sample Usage:

```puppet
registry::service { puppet:
  ensure       => present,
  display_name => 'Puppet Agent',
  description  => 'Periodically fetches and applies
                   configurations from a Puppet Server.',
  command      => 'C:\PuppetLabs\Puppet\service\daemon.bat',
}
```

#### Parameters

The following parameters are available in the `registry::service` defined type:

* [`ensure`](#-registry--service--ensure)
* [`display_name`](#-registry--service--display_name)
* [`description`](#-registry--service--description)
* [`command`](#-registry--service--command)
* [`start`](#-registry--service--start)

##### <a name="-registry--service--ensure"></a>`ensure`

Data type: `Enum['present', 'absent', 'UNSET']`

Ensures the presence or absence of a registry key. Valid values: 'present', 'absent', 'UNSET'.

Default value: `'UNSET'`

##### <a name="-registry--service--display_name"></a>`display_name`

Data type: `String[1]`

The Display Name of the service.  Defaults to the title of the resource.

Default value: `'UNSET'`

##### <a name="-registry--service--description"></a>`description`

Data type: `String[1]`

A description of the service. String value set to 'UNSET' by default.

Default value: `'UNSET'`

##### <a name="-registry--service--command"></a>`command`

Data type: `String[1]`

The command to execute. Set to 'UNSET' by default.

Default value: `'UNSET'`

##### <a name="-registry--service--start"></a>`start`

Data type: `Enum['automatic', 'manual', 'disabled', 'UNSET']`

The starting mode of the service.  (Note, the native service
resource can also be used to manage this setting.)
Valid values: 'automatic', 'manual', 'disabled'

Default value: `'UNSET'`

### <a name="registry--value"></a>`registry::value`

Actions:
  - Manage the parent key if not already managed.
  - Manage the value

Requires:
  - Registry Module
  - Stdlib Module

* **Note** This defined resource type provides a higher level of abstraction on top of
the registry_key and registry_value resources.  Using this defined resource
type, you do not need to explicitly manage the parent key for a particular
value.  Puppet will automatically manage the parent key for you.

#### Examples

##### This example will automatically manage the key. It will also create a value named 'puppetserver' inside this key.

```puppet
class myapp {
  registry::value { 'puppetserver':
    key => 'HKLM\Software\Vendor\PuppetLabs',
    data => 'puppet.puppetlabs.com',
  }
}
```

#### Parameters

The following parameters are available in the `registry::value` defined type:

* [`key`](#-registry--value--key)
* [`value`](#-registry--value--value)
* [`type`](#-registry--value--type)
* [`data`](#-registry--value--data)

##### <a name="-registry--value--key"></a>`key`

Data type: `Pattern[/^\w+/]`

The path of key the value will placed inside.

##### <a name="-registry--value--value"></a>`value`

Data type: `Optional[String]`

The name of the registry value to manage.  This will be copied from
the resource title if not specified.  The special value of
'(default)' may be used to manage the default value of the key.

Default value: `undef`

##### <a name="-registry--value--type"></a>`type`

Data type: `Pattern[/^\w+/]`

The type the registry value.  Defaults to 'string'.  See the output of
`puppet describe registry_value` for a list of supported types in the
"type" parameter.

Default value: `'string'`

##### <a name="-registry--value--data"></a>`data`

Data type:

```puppet
Optional[Variant[
      String,
      Numeric,
      Array[String]
  ]]
```

The data to place inside the registry value.

Default value: `undef`

## Resource types

### <a name="registry_key"></a>`registry_key`

Manages registry keys on Windows

#### Properties

The following properties are available in the `registry_key` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `registry_key` type.

* [`path`](#-registry_key--path)
* [`provider`](#-registry_key--provider)
* [`purge_values`](#-registry_key--purge_values)

##### <a name="-registry_key--path"></a>`path`

The path to the registry key to manage

##### <a name="-registry_key--provider"></a>`provider`

The specific backend to use for this `registry_key` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-registry_key--purge_values"></a>`purge_values`

Valid values: `true`, `false`

Common boolean for munging and validation.

Default value: `false`

### <a name="registry_value"></a>`registry_value`

Manages registry values on Windows systems.

#### Properties

The following properties are available in the `registry_value` type.

##### `data`

The data stored in the registry value.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `type`

Valid values: `string`, `array`, `dword`, `qword`, `binary`, `expand`

The Windows data type of the registry value.

Default value: `string`

#### Parameters

The following parameters are available in the `registry_value` type.

* [`path`](#-registry_value--path)
* [`provider`](#-registry_value--provider)

##### <a name="-registry_value--path"></a>`path`

The path to the registry value to manage.

##### <a name="-registry_value--provider"></a>`provider`

The specific backend to use for this `registry_value` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

